@@ -10,12 +10,6 @@ except ImportError:
     from buildconfig.config_unix import DependencyProg
 
 
-try:
-    basestring_ = basestring
-except NameError:
-    #python 3.
-    basestring_ = str
-
 class Dependency:
     libext = '.dylib'
     def __init__(self, name, checkhead, checklib, libs):
@@ -34,7 +28,7 @@ class Dependency:
         incnames = self.checkhead
         libnames = self.checklib, self.name.lower()
         for dir in incdirs:
-            if isinstance(incnames, basestring_):
+            if isinstance(incnames, str):
                 incnames = [incnames]
 
             for incname in incnames:
@@ -50,10 +44,10 @@ class Dependency:
                     self.lib_dir = dir
                     break
         if self.inc_dir and (self.lib_dir or not self.checklib):
-            print (self.name + '        '[len(self.name):] + ': found')
+            print(self.name + '        '[len(self.name):] + ': found')
             self.found = 1
         else:
-            print (self.name + '        '[len(self.name):] + ': not found')
+            print(self.name + '        '[len(self.name):] + ': not found')
 
 class FrameworkDependency(Dependency):
     def configure(self, incdirs, libdirs):
@@ -62,16 +56,16 @@ class FrameworkDependency(Dependency):
             n += 'Library/Frameworks/'
             fmwk = n + self.libs + '.framework/Versions/Current/'
             if os.path.isdir(fmwk):
-                print ('Framework ' + self.libs + ' found')
+                print('Framework ' + self.libs + ' found')
                 self.found = 1
                 self.inc_dir = fmwk + 'Headers'
                 self.cflags = (
-                    '-Xlinker "-framework" -Xlinker "' + self.libs + '"' +
-                    ' -Xlinker "-F' + n + '"')
+                    f'-Xlinker "-framework" -Xlinker "{self.libs}"' +
+                    f' -Xlinker "-F{n}"')
                 self.origlib = self.libs
                 self.libs = ''
                 return
-        print ('Framework ' + self.libs + ' not found')
+        print('Framework ' + self.libs + ' not found')
 
 
 class DependencyPython:
@@ -100,9 +94,9 @@ class DependencyPython:
             else:
                 self.inc_dir = os.path.split(fullpath)[0]
         if self.found:
-            print (self.name + '        '[len(self.name):] + ': found', self.ver)
+            print(self.name + '        '[len(self.name):] + ': found', self.ver)
         else:
-            print (self.name + '        '[len(self.name):] + ': not found')
+            print(self.name + '        '[len(self.name):] + ': not found')
 
 def find_freetype():
     """ modern freetype uses pkg-config. However, some older systems don't have that.
@@ -126,27 +120,14 @@ def find_freetype():
 
 
 
-def main(sdl2=False):
-
-    if sdl2:
-        DEPS = [
-            [DependencyProg('SDL', 'SDL_CONFIG', 'sdl2-config', '2.0', ['sdl'])],
-            [Dependency('FONT', ['SDL_ttf.h', 'SDL2/SDL_ttf.h'], 'libSDL2_ttf', ['SDL2_ttf'])],
-            [Dependency('IMAGE', ['SDL_image.h', 'SDL2/SDL_image.h'], 'libSDL2_image', ['SDL2_image'])],
-            [Dependency('MIXER', ['SDL_mixer.h', 'SDL2/SDL_mixer.h'], 'libSDL2_mixer', ['SDL2_mixer'])],
-        ]
-    else:
-        DEPS = [
-            [DependencyProg('SDL', 'SDL_CONFIG', 'sdl-config', '1.2', ['sdl']),
-                 FrameworkDependency('SDL', 'SDL.h', 'libSDL', 'SDL')],
-            [Dependency('FONT', ['SDL_ttf.h', 'SDL/SDL_ttf.h'], 'libSDL_ttf', ['SDL_ttf']),
-                 FrameworkDependency('FONT', 'SDL_ttf.h', 'libSDL_ttf', 'SDL_ttf')],
-            [Dependency('IMAGE', ['SDL_image.h', 'SDL/SDL_image.h'], 'libSDL_image', ['SDL_image']),
-                 FrameworkDependency('IMAGE', 'SDL_image.h', 'libSDL_image', 'SDL_image')],
-            [Dependency('MIXER', ['SDL_mixer.h', 'SDL/SDL_mixer.h'], 'libSDL_mixer', ['SDL_mixer']),
-                 FrameworkDependency('MIXER', 'SDL_mixer.h', 'libSDL_mixer', 'SDL_mixer')],
-        ]
+def main(auto_config=False):
 
+    DEPS = [
+        [DependencyProg('SDL', 'SDL_CONFIG', 'sdl2-config', '2.0', ['sdl'])],
+        [Dependency('FONT', ['SDL_ttf.h', 'SDL2/SDL_ttf.h'], 'libSDL2_ttf', ['SDL2_ttf'])],
+        [Dependency('IMAGE', ['SDL_image.h', 'SDL2/SDL_image.h'], 'libSDL2_image', ['SDL2_image'])],
+        [Dependency('MIXER', ['SDL_mixer.h', 'SDL2/SDL_mixer.h'], 'libSDL2_mixer', ['SDL2_mixer'])],
+    ]
 
     DEPS.extend([
         Dependency('PNG', 'png.h', 'libpng', ['png']),
@@ -158,12 +139,9 @@ def main(sdl2=False):
         # Dependency('SCRAP', '','',[]),
     ])
 
-    print ('Hunting dependencies...')
+    print('Hunting dependencies...')
     incdirs = ['/usr/local/include', '/opt/homebrew/include']
-    if sdl2:
-        incdirs.extend(['/usr/local/include/SDL2', '/opt/homebrew/include/SDL2', '/opt/local/include/SDL2'])
-    else:
-        incdirs.extend(['/usr/local/include/SDL', '/opt/homebrew/include/SDL', '/opt/local/include/SDL'])
+    incdirs.extend(['/usr/local/include/SDL2', '/opt/homebrew/include/SDL2', '/opt/local/include/SDL2'])
 
     incdirs.extend([
        #'/usr/X11/include',
@@ -196,5 +174,5 @@ def main(sdl2=False):
 
 
 if __name__ == '__main__':
-    print ("""This is the configuration subscript for OSX Darwin.
+    print("""This is the configuration subscript for OSX Darwin.
              Please run "config.py" for full configuration.""")
