@@ -9,7 +9,8 @@ try:
 except ImportError:
     from buildconfig.setup_win_common import get_definitions
 
-import os, sys
+import os
+import sys
 import re
 import logging
 import subprocess
@@ -26,7 +27,7 @@ def as_machine_type(size):
         return "x86"
     if size == 64:
         return "x64"
-    raise BuildError("Unknown pointer size {}".format(size))
+    raise ValueError("Unknown pointer size {}".format(size))
 
 def get_machine_type():
     return as_machine_type(get_ptr_size())
@@ -35,11 +36,11 @@ def get_absolute_win_path(msys2_path):
     output = subprocess.run(['cygpath', '-w', msys2_path],
                             capture_output=True, text=True)
     if output.returncode != 0:
-        raise Exception("Could not get absolute Windows path: %s"%msys2_path)
+        raise Exception(f"Could not get absolute Windows path: {msys2_path}")
     else:
         return output.stdout.strip()
 
-class Dependency(object):
+class Dependency:
     huntpaths = ['..', '../..', '../*', '../../*']
     inc_hunt = ['include']
     lib_hunt = ['lib']
@@ -91,24 +92,24 @@ class Dependency(object):
                 self.libs[0] = os.path.splitext(self.fallback_lib[2])[0].lstrip('lib').rstrip('.dll')
             if self.inc_dir and self.lib_dir:
                 if print_result:
-                    print ("Path for %s found." % self.name)
+                    print(f"Path for {self.name} found.")
                 return True
             if print_result:
-                print ("Path for %s not found." % self.name)
+                print(f"Path for {self.name} not found.")
                 for info in self.prune_info:
                     print(info)
                 if self.required:
-                    print ('Too bad that is a requirement! Hand-fix the "Setup"')
+                    print('Too bad that is a requirement! Hand-fix the "Setup"')
             return False
         elif len(self.paths) == 1:
             self.path = self.paths[0]
             if print_result:
-                print ("Path for %s: %s" % (self.name, self.path))
+                print(f"Path for {self.name}: {self.path}")
         else:
             logging.warning("Multiple paths to choose from:%s", self.paths)
             self.path = self.paths[0]
             if print_result:
-                print ("Path for %s: %s" % (self.name, self.path))
+                print(f"Path for {self.name}: {self.path}")
         return True
 
     def matchfile(self, path, match):
@@ -183,11 +184,11 @@ class Dependency(object):
                     # MSYS2: lib<name>.dll.a -> <name>
                     self.libs[0] = os.path.splitext(lib_info[2])[0].lstrip('lib').rstrip('.dll')
         if self.lib_dir and self.inc_dir:
-            print("...Library directory for %s: %s" % (self.name, self.lib_dir))
-            print("...Include directory for %s: %s" % (self.name, self.inc_dir))
+            print(f"...Library directory for {self.name}: {self.lib_dir}")
+            print(f"...Include directory for {self.name}: {self.inc_dir}")
             self.found = True
 
-class DependencyPython(object):
+class DependencyPython:
     def __init__(self, name, module, header):
         self.name = name
         self.lib_dir = ''
@@ -213,9 +214,9 @@ class DependencyPython(object):
             else:
                 self.inc_dir = os.path.split(fullpath)[0]
         if self.found:
-            print ("%-8.8s: found %s" % (self.name, self.ver))
+            print("%-8.8s: found %s" % (self.name, self.ver))
         else:
-            print ("%-8.8s: not found" % self.name)
+            print("%-8.8s: not found" % self.name)
 
 class DependencyDLL(Dependency):
     def __init__(self, dll_regex, lib=None, wildcards=None, libs=None, link=None):
@@ -240,12 +241,12 @@ class DependencyDLL(Dependency):
             self.check_roots()
 
         if self.lib_dir != '_':
-            print ("DLL for %s: %s" % (self.lib_name, self.lib_dir))
+            print(f"DLL for {self.lib_name}: {self.lib_dir}")
             self.found = True
         else:
-            print ("No DLL for %s: not found!" % (self.lib_name))
+            print(f"No DLL for {self.lib_name}: not found!")
             if self.required:
-                print ('Too bad that is a requirement! Hand-fix the "Setup"')
+                print('Too bad that is a requirement! Hand-fix the "Setup"')
 
     def check_roots(self):
         for p in self.huntpaths:
@@ -268,7 +269,7 @@ class DependencyDLL(Dependency):
                         return True
         return False
 
-class DependencyDummy(object):
+class DependencyDummy:
     def __init__(self, name):
         self.name = name
         self.inc_dir = None
@@ -280,7 +281,7 @@ class DependencyDummy(object):
     def configure(self):
         pass
 
-class DependencyWin(object):
+class DependencyWin:
     def __init__(self, name, cflags):
         self.name = name
         self.inc_dir = None
@@ -292,7 +293,7 @@ class DependencyWin(object):
     def configure(self):
         pass
 
-class DependencyGroup(object):
+class DependencyGroup:
     def __init__(self):
         self.dependencies =[]
         self.dlls = []
@@ -323,7 +324,7 @@ class DependencyGroup(object):
                     link = d
                     break
             else:
-                raise KeyError("Link lib %s not found" % link_lib)
+                raise KeyError(f"Link lib {link_lib} not found")
         dep = DependencyDLL(dll_regex, lib, wildcards, libs, link)
         self.dlls.append(dep)
         return dep
@@ -354,12 +355,9 @@ class DependencyGroup(object):
                         from buildconfig import vstools
                     from os.path import splitext
                     nonext_name = splitext(d.lib_dir)[0]
-                    def_file = '%s.def' % nonext_name
+                    def_file = f'{nonext_name}.def'
                     basename = os.path.basename(nonext_name)
-                    print('Building lib from %s: %s.lib...' % (
-                        os.path.basename(d.lib_dir),
-                        basename
-                    ))
+                    print(f'Building lib from {os.path.basename(d.lib_dir)}: {basename}.lib...')
                     vstools.dump_def(d.lib_dir, def_file=def_file)
                     vstools.lib_from_def(def_file)
                     d.link.lib_dir = os.path.dirname(d.lib_dir)
@@ -367,10 +365,8 @@ class DependencyGroup(object):
                     d.link.configure()
 
     def __iter__(self):
-        for d in self.dependencies:
-            yield d
-        for d in self.dlls:
-            yield d
+        yield from self.dependencies
+        yield from self.dlls
 
 def _add_sdl2_dll_deps(DEPS):
     # MIXER
@@ -406,7 +402,7 @@ def setup_prebuilt_sdl2(prebuilt_dir):
     sdlDep.inc_dir = [
         os.path.join(prebuilt_dir, 'include').replace('\\', '/')
     ]
-    sdlDep.inc_dir.append('%s/SDL2' % sdlDep.inc_dir[0])
+    sdlDep.inc_dir.append(f'{sdlDep.inc_dir[0]}/SDL2')
     fontDep = DEPS.add('FONT', 'SDL2_ttf', ['SDL2_ttf-[2-9].*'], r'(lib){0,1}SDL2_ttf\.dll$', ['SDL', 'z', 'freetype'])
     imageDep = DEPS.add('IMAGE', 'SDL2_image', ['SDL2_image-[1-9].*'], r'(lib){0,1}SDL2_image\.dll$',
                         ['SDL', 'jpeg', 'png', 'tiff'], 0)
@@ -423,7 +419,7 @@ def setup_prebuilt_sdl2(prebuilt_dir):
     ftDep.inc_dir = [
         os.path.join(prebuilt_dir, 'include').replace('\\', '/')
     ]
-    ftDep.inc_dir.append('%s/freetype2' % ftDep.inc_dir[0])
+    ftDep.inc_dir.append(f'{ftDep.inc_dir[0]}/freetype2')
     ftDep.found = True
 
     png = DEPS.add('PNG', 'png', ['SDL2_image-[2-9].*', 'libpng-[1-9].*'], r'(png|libpng)[-0-9]*\.dll$', ['z'],
@@ -467,10 +463,7 @@ def setup_prebuilt_sdl2(prebuilt_dir):
     return list(DEPS)
 
 
-def main(sdl2=True):
-    if not sdl2:
-        raise Exception("Building SDL1.x on MSYS2 is not supported")
-
+def main(auto_config=False):
     machine_type = get_machine_type()
 
     # config MSYS2 always requires prebuilt dependencies, in the
@@ -507,11 +500,10 @@ def main(sdl2=True):
     prebuilt_dir = get_absolute_win_path(prebuilt_msys_dir[machine_type])
     return setup_prebuilt_sdl2(prebuilt_dir)
 
-if __name__ == '__main__':
-    print ("""This is the configuration subscript for MSYS2.
-Please run "config.py" for full configuration.""")
 
-    import sys
+if __name__ == '__main__':
+    print("""This is the configuration subscript for MSYS2.
+Please run "config.py" for full configuration.""")
     if "--download" in sys.argv:
         try:
             from . import download_msys2_prebuilt
