@@ -11,6 +11,7 @@
 #define DOC_COLORNORMALIZE "normalize() -> tuple\nReturns the normalized RGBA values of the Color."
 #define DOC_COLORCORRECTGAMMA "correct_gamma (gamma) -> Color\nApplies a certain gamma value to the Color."
 #define DOC_COLORSETLENGTH "set_length(len) -> None\nSet the number of elements in the Color to 1,2,3, or 4."
+#define DOC_COLORGRAYSCALE "grayscale() -> Color\nreturns the grayscale of a Color"
 #define DOC_COLORLERP "lerp(Color, float) -> Color\nreturns a linear interpolation to the given Color."
 #define DOC_COLORPREMULALPHA "premul_alpha() -> Color\nreturns a Color where the r,g,b components have been multiplied by the alpha."
 #define DOC_COLORUPDATE "update(r, g, b) -> None\nupdate(r, g, b, a=255) -> None\nupdate(color_value) -> None\nSets the elements of the color"
@@ -70,6 +71,10 @@ pygame.Color.set_length
  set_length(len) -> None
 Set the number of elements in the Color to 1,2,3, or 4.
 
+pygame.Color.grayscale
+ grayscale() -> Color
+returns the grayscale of a Color
+
 pygame.Color.lerp
  lerp(Color, float) -> Color
 returns a linear interpolation to the given Color.
